@@ -173,6 +173,45 @@ SourceLocation RewriteUtils::getEndLocationAfter(SourceRange Range,
   return EndLoc.getLocWithOffset(Offset);
 }
 
+clang::SourceRange RewriteUtils::getDeclFullSourceRange(const clang::Decl* D)
+{
+  SourceRange Range = D->getSourceRange();
+
+  // Ensure that template parameters are included in the def range
+  if (auto* FD = dyn_cast<FunctionDecl>(D)) {
+    if (FD->getNumTemplateParameterLists()) {
+      TemplateParameterList* TPL = FD->getTemplateParameterList(0);
+      Range.setBegin(TPL->getSourceRange().getBegin());
+    } else if (auto* T = FD->getDescribedTemplate()) {
+      TemplateParameterList* TPL = T->getTemplateParameters();
+      Range.setBegin(TPL->getSourceRange().getBegin());
+    }
+  } else if (auto* TD = dyn_cast<TagDecl>(D)) {
+    if (TD->getNumTemplateParameterLists()) {
+      TemplateParameterList* TPL = TD->getTemplateParameterList(0);
+      Range.setBegin(TPL->getSourceRange().getBegin());
+    } else if (auto* T = TD->getDescribedTemplate()) {
+      TemplateParameterList* TPL = T->getTemplateParameters();
+      Range.setBegin(TPL->getSourceRange().getBegin());
+    }
+  }
+
+
+  // Include the semicolon into the declaration. 
+  // See DeclPrinter::VisitDeclContext in clang source code for all cases.
+  bool HasSemicolon = true;
+  if (auto* FD = dyn_cast<FunctionDecl>(D)) {
+    HasSemicolon = !FD->doesThisDeclarationHaveABody();
+  } else if (auto* FTD = dyn_cast<FunctionTemplateDecl>(D)) {
+    HasSemicolon = !FTD->getTemplatedDecl()->isThisDeclarationADefinition();
+  }
+
+  if (HasSemicolon)
+    Range.setEnd(getEndLocationAfter(Range, ';'));
+
+  return Range;
+}
+
 SourceLocation RewriteUtils::getLocationAfter(SourceLocation Loc, 
                                                 char Symbol)
 {
@@ -736,15 +775,9 @@ std::string RewriteUtils::getStmtIndentString(Stmt *S,
   StringRef MB = SrcManager->getBufferData(FID);
  
   unsigned lineNo = SrcManager->getLineNumber(FID, StartOffset) - 1;
-#if LLVM_VERSION_MAJOR >= 12
   const SrcMgr::ContentCache&
       Content = SrcManager->getSLocEntry(FID).getFile().getContentCache();
   unsigned lineOffs = Content.SourceLineCache[lineNo];
-#else
-  const SrcMgr::ContentCache *
-      Content = SrcManager->getSLocEntry(FID).getFile().getContentCache();
-  unsigned lineOffs = Content->SourceLineCache[lineNo];
-#endif
  
   // Find the whitespace at the start of the line.
   StringRef indentSpace;
@@ -927,13 +960,11 @@ bool RewriteUtils::addStringAfterVarDecl(const VarDecl *VD,
   return !(TheRewriter->InsertText(LocEnd, "\n" + Str));
 }
 
-bool RewriteUtils::addStringAfterFuncDecl(const FunctionDecl *FD,
-                                          const std::string &Str)
+bool RewriteUtils::addStringAfterDecl(const Decl *D, const std::string &Str)
 {
-  SourceRange FDRange = FD->getSourceRange();
-  SourceLocation LocEnd = getEndLocationAfter(FDRange, ';');
+  SourceRange Range = getDeclFullSourceRange(D);
   
-  return !(TheRewriter->InsertText(LocEnd, "\n" + Str));
+  return !(TheRewriter->InsertText(Range.getEnd(), "\n" + Str));
 }
 
 // This function is an experimental one. It doesn't work
@@ -1832,24 +1863,47 @@ bool RewriteUtils::removeCXXCtorInitializer(const CXXCtorInitializer *Init,
   }
 }
 
+bool RewriteUtils::removeTemplateArgument(const clang::DeclRefExpr* DRE, unsigned Idx)
+{
+  assert(Idx < DRE->getNumTemplateArgs());
+
+  const TemplateArgumentLoc* Args = DRE->getTemplateArgs();
+  if (DRE->getNumTemplateArgs() == 1) {
+    return !TheRewriter->RemoveText({ DRE->getLAngleLoc(), DRE->getRAngleLoc() });
+  } else if (Idx == 0) {
+    return removeTextUntil(Args[Idx].getSourceRange(), ',');
+  } else {
+    return removeTextFromLeftAt(Args[Idx].getSourceRange(), ',', Args[Idx].getSourceRange().getEnd());
+  }
+}
+
+bool RewriteUtils::removeTemplateParameter(const clang::TemplateParameterList* TPL, unsigned Idx)
+{
+  assert(Idx < TPL->size());
+
+  const NamedDecl* Param = TPL->getParam(Idx);
+  if (TPL->size() == 1) {
+    return !TheRewriter->RemoveText({ TPL->getTemplateLoc(), TPL->getRAngleLoc() });
+  } else if (Idx == 0) {
+    return removeTextUntil(Param->getSourceRange(), ',');
+  } else {
+    return removeTextFromLeftAt(Param->getSourceRange(), ',', Param->getEndLoc());
+  }
+}
+
 bool RewriteUtils::removeClassDecls(const CXXRecordDecl *CXXRD)
 {
-  for (CXXRecordDecl::redecl_iterator I = CXXRD->redecls_begin(),
-      E = CXXRD->redecls_end(); I != E; ++I) {
-    SourceRange Range = (*I)->getSourceRange();
-    SourceLocation LocEnd;
-    if ((*I)->isThisDeclarationADefinition()) {
-      LocEnd = (*I)->getBraceRange().getEnd();
-      if (LocEnd.isValid())
-        LocEnd = getLocationUntil(LocEnd, ';');
-      else
-        LocEnd = getEndLocationUntil(Range, ';');
-    }
-    else {
-      LocEnd = getEndLocationUntil(Range, ';');
-    }
-    TheRewriter->RemoveText(SourceRange(Range.getBegin(), LocEnd));
+  if (auto* CTSD = dyn_cast<ClassTemplateSpecializationDecl>(CXXRD)) {
+    if (CTSD->getSpecializationKind() == TSK_ImplicitInstantiation)
+      CXXRD = CTSD->getSpecializedTemplate()->getTemplatedDecl();
   }
+
+  for (const TagDecl* Redecl : CXXRD->redecls()) {
+    SourceRange Range = getDeclFullSourceRange(Redecl);
+    if (Range.isValid())
+      TheRewriter->RemoveText(Range);
+  }
+
   return true;
 }
 
