@@ -12,7 +12,9 @@ class SpecialATestCase(unittest.TestCase):
 
     def test_a(self):
         with tempfile.NamedTemporaryFile(mode='w', delete=False) as tmp_file:
-            tmp_file.write("// Useless comment\ntransparent_crc(g_376.f0, 'g_376.f0', print_hash_value);\ntransparent_crc(g_1194[i].f0, 'g_1194[i].f0', print_hash_value);\nint a = 9;")
+            tmp_file.write(
+                "// Useless comment\ntransparent_crc(g_376.f0, 'g_376.f0', print_hash_value);\ntransparent_crc(g_1194[i].f0, 'g_1194[i].f0', print_hash_value);\nint a = 9;"
+            )
 
         iterate_pass(self.pass_, tmp_file.name)
 
@@ -21,14 +23,19 @@ class SpecialATestCase(unittest.TestCase):
 
         os.unlink(tmp_file.name)
 
-        self.assertEqual(variant, "// Useless comment\nprintf('%d\\n', (int)g_376.f0);\nprintf('%d\\n', (int)g_1194[i].f0);\nint a = 9;")
+        self.assertEqual(
+            variant,
+            "// Useless comment\nprintf('%d\\n', (int)g_376.f0);\nprintf('%d\\n', (int)g_1194[i].f0);\nint a = 9;",
+        )
 
     def test_success_a(self):
         with tempfile.NamedTemporaryFile(mode='w', delete=False) as tmp_file:
-            tmp_file.write("// Useless comment\ntransparent_crc(g_376.f0, 'g_376.f0', print_hash_value);\ntransparent_crc(g_1194[i].f0, 'g_1194[i].f0', print_hash_value);\nint a = 9;")
+            tmp_file.write(
+                "// Useless comment\ntransparent_crc(g_376.f0, 'g_376.f0', print_hash_value);\ntransparent_crc(g_1194[i].f0, 'g_1194[i].f0', print_hash_value);\nint a = 9;"
+            )
 
         state = self.pass_.new(tmp_file.name)
-        (result, state) = self.pass_.transform(tmp_file.name, state, None)
+        (_result, state) = self.pass_.transform(tmp_file.name, state, None)
 
         iterate_pass(self.pass_, tmp_file.name)
 
@@ -37,7 +44,10 @@ class SpecialATestCase(unittest.TestCase):
 
         os.unlink(tmp_file.name)
 
-        self.assertEqual(variant, "// Useless comment\nprintf('%d\\n', (int)g_376.f0);\nprintf('%d\\n', (int)g_1194[i].f0);\nint a = 9;")
+        self.assertEqual(
+            variant,
+            "// Useless comment\nprintf('%d\\n', (int)g_376.f0);\nprintf('%d\\n', (int)g_1194[i].f0);\nint a = 9;",
+        )
 
 
 class SpecialBTestCase(unittest.TestCase):
